"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.recordToModel = exports.PrivilegedPrincipalService = void 0;
const service_1 = require("../privilege/service");
const database_1 = require("../database");
/**
 * This class provides a wrapper around the principal service APIs.
 *
 * It ensures that the caller (the personal or app that's logged in) has
 * the appropriate privileges to read the associated data.
 */
class PrivilegedPrincipalService {
    constructor(actor) {
        this.privileges = new service_1.LazyPrivilegeBox(actor);
    }
    async findAll(type) {
        const filters = {};
        if (type) {
            filters.type = userTypeToInt(type);
        }
        const result = await (0, database_1.default)('principals')
            .where(filters);
        const principals = [];
        for (const principal of result) {
            principals.push(recordToModel(principal));
        }
        return principals;
    }
    async checkPrivilege(privilege, resource) {
        await this.privileges.ready();
        this.privileges.require(privilege, resource);
    }
}
exports.PrivilegedPrincipalService = PrivilegedPrincipalService;
function userTypeToInt(input) {
    switch (input) {
        case 'user': return 1;
        case 'app': return 2;
        case 'group': return 3;
    }
}
function userTypeIntToUserType(input) {
    switch (input) {
        case 1: return 'user';
        case 2: return 'app';
        case 3: return 'group';
        default:
            throw new Error('Unknown user type id: ' + input);
    }
}
function recordToModel(user) {
    return {
        id: user.id,
        href: `/${userTypeIntToUserType(user.type)}/${user.external_id}`,
        identity: user.identity,
        externalId: user.external_id,
        nickname: user.nickname,
        createdAt: new Date(user.created_at),
        modifiedAt: new Date(user.modified_at),
        type: userTypeIntToUserType(user.type),
        active: !!user.active,
        system: !!user.system,
    };
}
exports.recordToModel = recordToModel;
//# sourceMappingURL=privileged-service.js.map